from zope.interface import Interface


class ITestServer(Interface):
    """A test server is a 'remote' service that runs tests."""

    def find_tests(name):
        """Iterate over a list of tests that match `name`.

        How `name` might match a test is at the implementation's discretion.
        One way might be to treat `name` as a fully-qualified Python name that
        contains a bunch of tests. Another might be to treat `name` as a
        regular expression that matches tests.

        The results of the iterator should be strings that uniquely identify a
        test. Each of these strings should be able to be passed to runTest.

        Calling `findTests` on any of the names yielded should yield exactly
        that name.
        """

    def run_tests(name, result):
        """Run all the tests that match `name`."""
