"""Tests for our eventloop abstraction."""

from tribunal.eventloop import BlockingLoop, GtkLoop
from tribunal.testing import TestCase


class TestGtkLoop(TestCase):

    def get_loop(self):
        return GtkLoop()

    def setUp(self):
        self.loop = self.get_loop()

    def test_loop_is_not_running(self):
        self.assertEqual(False, self.loop.is_running())

    def test_start_then_stop(self):
        def stop_if_running():
            if self.loop.is_running():
                self.loop.stop()
            return True
        self.loop.run_when_idle(stop_if_running)
        self.loop.start()
        self.assertEqual(False, self.loop.is_running())

    def test_idle_functions_not_called_after_stop(self):
        log = []
        def quit_then_add():
            self.loop.stop()
            self.loop.run_when_idle(lambda: log.append('foo'))
        self.loop.run_when_idle(quit_then_add)
        self.loop.start()
        self.assertEqual([], log)

    # XXX: Would like to test that run_when_idle methods are called until they
    # return False. Not sure how.


class TestBlockingLoop(TestGtkLoop):

    def get_loop(self):
        return BlockingLoop()
