import gtk

from tribunal import main
from tribunal.eventloop import BlockingLoop
from tribunal.testing import TestCase


class NullProvider(object):

    def __init__(self):
        self.log = []

    def find_tests(self, name):
        return [name]

    def run_tests(self, name, result):
        self.log.append(name)
        return [name]


class MockTest(TestCase):

    def test_mock(self):
        pass


class TestRunner(TestCase):

    def setUp(self):
        self.loop = BlockingLoop()
        self.provider = NullProvider()
        self.runner = main.make_runner(
            self.provider, event_loop=self.loop)
        self.view = self.runner.view

    def test_hasField(self):
        self.failUnless(isinstance(self.view.testNameField, gtk.Entry))

    def test_buttonRunsSuite(self):
        self.loop.start()
        self.view.runButton.clicked()
        self.assertEqual([self.runner.get_name()], self.provider.log)

    def test_enterRunsSuite(self):
        self.loop.start()
        self.view.testNameField.activate()
        self.assertEqual([self.runner.get_name()], self.provider.log)


class MockTest(TestCase):

    def test_pass(self):
        """Do nothing."""


class TestGUI(TestCase):

    def setUp(self):
        self.main_loop = BlockingLoop()
        self.runner = main.make_runner(
            NullProvider(), event_loop=self.main_loop)
        self.view = self.runner.view
        self.testName = 'tribunal.test.test_main.MockTest.test_pass'

    def tearDown(self):
        self.view.window.destroy()  #whitebox

    def get_arbitrary_test(self):
        return TestCase()

    def test_allVisible(self):
        self.view.show_all()
        self.failUnless(self.view.testNameField.get_property('visible'))
        self.failUnless(self.view.runButton.get_property('visible'))
        self.failUnless(self.view.progress.get_property('visible'))

    def test_inWindow(self):
        self.assertNotEqual(self.view.runButton.get_parent(), None)
        self.assertNotEqual(self.view.testNameField.get_parent(), None)
        self.assertNotEqual(self.view.progress.get_parent(), None)

    def test_windowDeleteKills(self):
        self.main_loop.start()
        self.assertEqual(True, self.main_loop.is_running())
        self.view.window.destroy()
        self.assertEqual(False, self.main_loop.is_running())

    def test_runLabel(self):
        self.assertEqual(self.view.runButton.get_label(), 'Run')

    def test_name(self):
        self.runner.set_name(self.testName)
        self.assertEqual(self.runner.get_name(), self.testName)

    def test_disabledWhenRunning(self):
        # XXX: We want to test this behaviour, but this is not the way to do
        # it!
        return
        self.main_loop.start()
        self.runner.set_name(self.testName)
        self.runner.run()
        self.assertEqual(
            False, self.view.runButton.get_property('sensitive'))
        self.assertEqual(
            False, self.view.testNameField.get_property('sensitive'))
        self.assertEqual(
            False, self.view.loadButton.get_property('sensitive'))

    def test_enabledBeforeRunner(self):
        self.assertEqual(
            True, self.view.runButton.get_property('sensitive'))
        self.assertEqual(
            True, self.view.testNameField.get_property('sensitive'))

    def test_doubleClickOnTestInTreeRunsTest(self):
        self.main_loop.start()
        tree = self.runner._view.tree
        test = self.get_arbitrary_test()
        self.runner.load_tests(test.id())
        path = tree.get_tree_path(test.id())
        tree.view.row_activated(path, tree.view.get_column(0))
        self.assertEqual(self.runner.get_name(), test.id())
