from tribunal import progress
from tribunal.testing import TestCase


class MockProgressBar(progress.ProgressBar):
    queue_draw_called = False

    def queue_draw(self):
        self.queue_draw_called = True


class TestProgress(TestCase):
    def setUp(self):
        self.p = MockProgressBar()
        self.p.reset(10)

    def test_initialFraction(self):
        self.assertEqual(self.p.get_fraction(), 0)

    def test_stepIncrement(self):
        self.p.step(True)
        self.assertEqual(self.p.get_fraction(), 0.1)

    def test_resetRedraw(self):
        self.p.reset(10)
        self.assertEqual(self.p.queue_draw_called, True)

    def test_stepRedraw(self):
        self.p.step(True)
        self.assertEqual(self.p.queue_draw_called, True)

    def test_fullAfterAllSteps(self):
        for i in range(10):
            self.p.step(True)
        self.assertEqual(self.p.get_fraction(), 1)

    def _colorEqual(self, c1, c2):
        self.assertEqual(c1.red, c2.red)
        self.assertEqual(c1.green, c2.green)
        self.assertEqual(c1.blue, c2.blue)

    def test_color(self):
        self._colorEqual(self.p.get_color(), self.p.success)

    def test_colorOnFail(self):
        self.p.step(False)
        self._colorEqual(self.p.get_color(), self.p.failure)

    def test_resetProgress(self):
        self.p.step(False)
        self.p.reset(11)
        self.assertEqual(self.p._steps, 11) # whitebox
        self.assertEqual(self.p.get_fraction(), 0)
        self.assertEqual(self.p.get_color(), self.p.success)

    def test_zeroSteps(self):
        self.p.reset(0)
        self.assertEqual(0, self.p.get_fraction())


