import gtk

from tribunal import tree
from tribunal.testing import TestCase


class TestTestTree(TestCase):

    def setUp(self):
        view = gtk.TreeView()
        self.tree = tree.TreeSuite(view)

    def make_arbitrary_test(self):
        test_name = self.getUniqueString().replace('-', '_')
        setattr(self.__class__, test_name, lambda: None)
        self.addCleanup(delattr, self.__class__, test_name)
        return self.__class__(test_name)

    def get_test_ids(self, tree):
        """Get all the test ids in `tree`."""
        return list(tree._test_id_to_path.keys())

    def assertTestIDs(self, tree, test_ids):
        self.assertEqual(set(test_ids), set(self.get_test_ids(tree)))

    def _populate(self):
        x = self.tree.store.append(None, ('foo', 0))
        child = self.tree.store.append(x, ('bar', 0))
        self.tree.store.append(None, ('baz', 0))
        return child

    def test_clear(self):
        self._populate()
        self.tree._clear()
        self.assertTestIDs(self.tree, [])

    def test_addTestID(self):
        tests = [self.make_arbitrary_test() for i in range(3)]
        for test in tests:
            self.tree.add_test_id(test.id())
        self.assertTestIDs(self.tree, [test.id() for test in tests])
