__all__ = [
    'ExtendedResult',
    'load_glade',
    'TribunalWindow',
    ]

from gtk.glade import XML as gladeXML

from testtools import MultiTestResult

from tribunal import tree, progress
from tribunal.results import Results
from tribunal.util import sibpath


def load_glade():
    glade_filename = sibpath(__file__, 'ui.glade')
    return gladeXML(glade_filename)


class TribunalWindow(object):

    def __init__(self, glade_xml):
        self.glade = glade_xml
        self.window = glade_xml.get_widget('mainWindow')
        self.testNameField = glade_xml.get_widget('testNameEntry')
        self.runButton = glade_xml.get_widget('runButton')
        self.pane = glade_xml.get_widget('mainPane')
        self.scroll = glade_xml.get_widget('scrollWindow')
        self.statusBar = glade_xml.get_widget('statusBar')
        self.loadButton = glade_xml.get_widget('loadButton')
        self.tree = tree.TreeSuite(glade_xml.get_widget('testTree'))
        self.results = Results(glade_xml.get_widget('errors'))
        self.progress = progress.ProgressBar()
        glade_xml.get_widget('progressFrame').add(self.progress)
        self._lockOnRun = [
            self.testNameField, self.runButton, self.loadButton]
        self._context = self.statusBar.get_context_id('testCount')

    def get_test_result(self):
        return MultiTestResult(self.progress, self.tree, self.results)

    def done(self, tests_run):
        self.unlock_for_running()
        self.set_status(u'%d tests run' % (tests_run,))

    def show_all(self):
        self.window.show_all()

    def started(self):
        self.set_status('Running tests...')
        self.lock_for_running()

    def lock_for_running(self):
        for widget in self._lockOnRun:
            widget.set_sensitive(False)

    def unlock_for_running(self):
        for widget in self._lockOnRun:
            widget.set_sensitive(True)

    def set_status(self, text):
        self.statusBar.pop(self._context)
        self.statusBar.push(self._context, text)

    def tests_loaded(self, tests):
        for test_id in tests:
            self.tree.add_test_id(test_id)
        self.progress.reset(len(tests))
        self.results.clear()


class ExtendedResult(MultiTestResult):
    """Adapts TribunalWindow to an actual TestResult."""

    def __init__(self, tribunal_window):
        super(ExtendedResult, self).__init__(
            tribunal_window.get_test_result())
        self._view = tribunal_window
        self._started = False
        self._tests_run = 0

    def startTest(self, test):
        if not self._started:
            self._view.started()
            self._started = True
            self._tests_run = 0
        super(ExtendedResult, self).startTest(test)

    def stopTest(self, test):
        self._tests_run += 1
        super(ExtendedResult, self).stopTest(test)

    def done(self):
        super(ExtendedResult, self).done()
        self._view.done(self._tests_run)
